<!-- LMML 1.0 Conceptual Module ............................................. -->
<!-- file: LMML10-cmodel-10.mod ............................................. -->
<!--
    This is the modular Learning Material Markup Language, an implementation
    of the XML binding of the teachware-specific meta-model described in
    Christian Suess, Adaptive Knowledge Management: A Meta-Modeling
    Approach and its Binding to XML". In: Proceedings 11. Workshop Grundlagen
    von Datenbanken, Arbeitskreis Grundlagen von Informationssystemen im
    GI-Fachausschuss 2.5, Ploen, Germany, 2000,
    http://daisy.fmi.uni-passau.de/db/literatur.php3?key=S00

    This is a module file corresponding to the modularization mechanism as
    defined in "Building XHTML Modules",  W3C Working Draft 5 January 2000 ,
    http://www.w3.org/TR/2000/WD-xhtml-building-20000105

    Please use this formal public identifier to identify it:
        "-//DE.UNI-PASSAU.DAISY//ENTITIES LMML 1.0 Conceptual Model 1.0//EN"
    Please use this formal system identifier to identify it:
        "LMML10-cmodel-10.mod"

    Author:         Christian Suess <suess@fmi.uni-passau.de>
    Date:           Wednesday 12-Apr-2000   
    Last Changes:   Monday 15-May-2000

    This is SUBJECT TO CHANGE, pending final approval.
    Please send your questions, bug reports, comments, or
    suggestions for changes to suess@fmi.uni-passau.de
-->
<!--
    Conceptual Model

    This module replaces the former Learning Material Content Markup Language,
    LMCML. It describes the groupings of elements that make up common content
    models for LMML conceptual units.

    LMML has four basic content models:

    %Inline.class;             character-level elements
    %Incontentobject.class;    block-like elements within ContentObjects
    %Contentobject.class;      block-like elements ContentObjects
    %Conceptualunit.class;     document root elements

-->
<!--
 _______________________________________________________________________
|                                                   
|   Copyright 1999-2000 Christian Suess, University of Passau, Germany       
|   
|   All rights reserved.
|                                   
|   Permission to use, copy, modify, and distribute this document for
|   any purposes and without fee is hereby granted in perpetuity,
|   provided that the above copyright notice and this permission notice
|   appear in all copies of this document. 
|                                   
|   WE PROVIDE THIS DOCUMENT TO USER "AS IS."  WE DISCLAIM ALL  
|   WARRANTIES, EXPRESS OR IMPLIED, WITH RESPECT TO THIS DOCUMENT,  
|   INCLUDING THE WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A   
|   PARTICULAR PURPOSE.  IN NO EVENT SHALL WE BE LIABLE FOR ANY 
|   DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,    
|   OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA, OR  
|   PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE, OR OTHER 
|   TORTUOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OF    
|   THIS DOCUMENT.
|
|   If you modify the LMML modules and drivers in any way, label your DTDs
|   as a variant of LMML.
|_______________________________________________________________________
-->
<!--================ imported entities ===============================-->
<!-- from module LMML10-datatypes-10.mod -->
<!ENTITY % URI.datatype "">
<!ENTITY % Text.datatype "">
<!-- from module LMML10-framework-10.mod -->
<!ENTITY % Incontentobject.class "">
<!-- from module LMML10-metadata-10.mod -->
<!ENTITY % Conceptualunit.attrib "">
<!ENTITY % Contentobject.attrib "">
<!ENTITY % Audience.attrib "">
<!ENTITY % Restriction.attrib "">
<!ENTITY % Label.attrib "">
<!--================ content models ==================================-->
<!ENTITY % Contentobject.extra "">
<!ENTITY % Contentobject.class "paragraph | motivation | definition | remark | quotation %Contentobject.extra; ">
<!ENTITY % Conceptualunit.extra "">
<!-- ================inline elements==================================-->
<!-- simple inline quotations, see ContentObejct quotation for block-like quotation -->
<!ENTITY % Quot.content "(#PCDATA)">
<!ELEMENT quot %Quot.content;>
<!ATTLIST quot
	bibUnit %URI.datatype; #IMPLIED
	bibKey IDREF #REQUIRED
>
<!ENTITY % Emph.content "(#PCDATA)">
<!ELEMENT emph %Emph.content;>
<!ATTLIST emph
	label IDREF #IMPLIED
	index %Text.datatype; #IMPLIED
>
<!-- ================optional inblock elements ========================-->
<!-- short summary to be used e.g. in slide presentations -->
<!ELEMENT summary (#PCDATA)>
<!-- details to be used e.g. student text books -->
<!ELEMENT details (#PCDATA %Incontentobject.class;)*>
<!--================block elements=====================================-->
<!--================Teachware-specific Content Objects=================-->
<!--<!ENTITY % Contentobject.content "#PCDATA | (summary, details) %Incontentobject.class;">-->
<!ENTITY % Contentobject.content "#PCDATA %Incontentobject.class;">
<!ELEMENT motivation (%Contentobject.content;)*>
<!ATTLIST motivation
	%Contentobject.attrib; 
>
<!ELEMENT definition (%Contentobject.content;)*>
<!ATTLIST definition
	%Contentobject.attrib; 
>
<!ELEMENT paragraph (%Contentobject.content;)*>
<!ATTLIST paragraph
	%Contentobject.attrib; 
>
<!-- footnotes etc. -->
<!ELEMENT remark (%Contentobject.content;)*>
<!ATTLIST remark
	%Contentobject.attrib; 
	%Audience.attrib; 
>
<!ELEMENT example (%Contentobject.content;)*>
<!ATTLIST example
	%Contentobject.attrib; 
	type (pro | contra) #IMPLIED
>
<!ELEMENT exercise (question, solution?)>
<!ATTLIST exercise
	%Contentobject.attrib; 
>
<!ELEMENT question (%Contentobject.content;)*>
<!ELEMENT solution (%Contentobject.content;)*>

<!-- see also inline quotation quot -->
<!ELEMENT quotation (%Contentobject.content;)*>
<!ATTLIST quotation
	bibUnit %URI.datatype; #IMPLIED
	bibKey IDREF #REQUIRED
>
<!ELEMENT bibItem (#PCDATA)>
<!ATTLIST bibItem
	bibKey ID #REQUIRED
>
<!-- test can be redeclared in the driver file e.g. to use TML elements etc. -->
<!ELEMENT test (%Contentobject.content;)*>
<!ATTLIST test
	%Contentobject.attrib; 
>
<!-- =============== document root elements=====================================-->
<!--================Teachware-specific Conceptual Units=========================-->
<!ELEMENT courseUnit (#PCDATA | example | %Contentobject.class;)*>
<!ATTLIST courseUnit
	%Conceptualunit.attrib; 
>
<!ELEMENT trainingUnit (#PCDATA | exercise | remark | paragraph)*>
<!ATTLIST trainingUnit
	%Conceptualunit.attrib; 
>
<!ELEMENT evaluationUnit (#PCDATA | test | remark | paragraph)*>
<!ATTLIST evaluationUnit
	%Conceptualunit.attrib; 
>
<!ELEMENT exampleUnit (#PCDATA | example | remark | paragraph)*>
<!ATTLIST exampleUnit
	%Conceptualunit.attrib; 
>
<!ELEMENT annotationUnit (#PCDATA | %Contentobject.class;)*>
<!ATTLIST annotationUnit
	%Conceptualunit.attrib; 
>
<!ELEMENT coachingUnit (#PCDATA | remark | paragraph)*>
<!ATTLIST coachingUnit
	%Conceptualunit.attrib; 
>
<!ELEMENT bibUnit (#PCDATA | bibItem)*>
<!ATTLIST bibUnit
	%Label.attrib; 
	%Conceptualunit.attrib; 
>
<!ENTITY % Conceptualunit.class "courseUnit | trainingUnit | evaluationUnit | exampleUnit | annotationUnit | coachingUnit | bibUnit %Conceptualunit.extra;">
<!--================ document element content =================================-->
<!ENTITY % LMML.content "(%Conceptualunit.class;)">
<!-- end of LMML10-cmodel-10.mod -->
